@@ -1,3 +1,6 @@
+from defusedxml import ElementTree
+
+
 class HeaderLevels:
     def __init__(self, top=3):
         """Demotes all the headers of the document so the first level becomes
@@ -39,16 +42,44 @@ class AddClasses:
 
     def add_classes(self, md, result, state):
         """Find bare HTML tags and add classes to them."""
+        root = ElementTree.fromstring(result)
+
         for tag, classes in self.tags.items():
             if not isinstance(classes, tuple):
                 classes = (classes,)
 
-            result = result.replace(
-                f"<{tag}>", f"<{tag} class=\"{' '.join(classes)}\">"
-            )
+            self._process_tag(root, tag, classes)
 
-        return result
+        return ElementTree.tostring(root, encoding="unicode")
+
+    def _process_tag(self, root, tag, new_classes):
+        """Add `new_classes` to all `tag` elements in `root`."""
+        for el in root.iter(tag):
+            old_classes = el.get("class", "").split(" ")
+            classes = set((*old_classes, *new_classes))
+
+            el.set("class", " ".join(classes))
 
     def __call__(self, md):
         if md.renderer.NAME == "html":
             md.after_render_hooks.append(self.add_classes)
+
+
+class TargetBlankLinks:
+    """Add `target="_blank"` to all document links.
+
+    This only alters the rendering of the document, not its AST.
+    """
+
+    def add_targets(self, md, result, state):
+        """Find bare `<a>` tags and add targets to them."""
+        root = ElementTree.fromstring(result)
+
+        for el in root.iter("a"):
+            el.set("target", "_blank")
+
+        return ElementTree.tostring(root, encoding="unicode")
+
+    def __call__(self, md):
+        if md.renderer.NAME == "html":
+            md.after_render_hooks.append(self.add_targets)
